#
# spec file for package python-ptr
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ptr
Version:        22.7.12
Release:        1.4
Summary:        Parallel asyncio Python setup(cfg|py) test runner
License:        MIT
URL:            https://github.com/facebookincubator/ptr
Source:         https://files.pythonhosted.org/packages/source/p/ptr/ptr-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module tomli}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
# Conflicts on site-packages/ptr.py
Conflicts:      python-pytest-runner
BuildArch:      noarch
%python_subpackages

%description
Parallel asyncio Python setup.(cfg|py) test runner.

%prep
%setup -q -n ptr-%{version}
sed -i 's/test_config/_test_config/' ptr_tests.py
sed -i '1{/^#!/d}' *.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/ptr
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v ptr_tests

%post
%python_install_alternative ptr

%postun
%python_uninstall_alternative ptr

%files %{python_files}
%doc CHANGES.md README.md
%python_alternative %{_bindir}/ptr
%{python_sitelib}/ptr.py
%pycache_only %{python_sitelib}/__pycache__/ptr.*
%{python_sitelib}/ptr-%{version}.dist-info

%changelog
* Sun Jan  7 2024 Dirk Müller <dmueller@suse.com>
- update to 22.7.12:
  * 3.11 Supported - added metadata + made 3.11 CI pass
  * Add `pyproject.toml` user config support
  * Add basic Hypothesis fuzz testing
  * Learnt during US PyCon 2022
  * Add `pyproject.toml` basic PEP517 building support
  * This *(again)* will be the last 3.7 supported version
  * I forgot to remove + CI still passes so will leave for now :)
  * This will be the last 3.7 supported version
  * Why? Want a less buggy `asyncio.run` for starting asyncio
  * Reactivate `pylint` in CI
  * f-string all ptr strings
  * Drop python 3.6 CI + support
  * We're Meta now - Update copyrights due to comapny change name
  * 3.11 CI is failing due to depedencies. Will watch and fix
    asap.
  * Add Official Support and CI for Python 3.10
  * This will be the last release *(if no bugs present
    themselves)* for 3.6
  * Also start ci_latest running 3.11
  * Add usort to the family of CI options
  * Support floats for coverage comparisions in
    `required_coverage` - PR #108
  * Change `--print-cov` to work when `required_coverage` does
    not exist in ptr config - PR #109
  * Move tests out of install but include in sdist - PR #99 -
    Thanks @jayvdb
  * Test with 3.10 alphas via deadsnakes - PR #110
  * Misc f-string + lint/typing fixes
* Wed Dec 16 2020 Matej Cepl <mcepl@suse.com>
- Make tests working again.
* Mon May 18 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Wed Mar 18 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 20.2.26:
  - Add support for passing `--system-site-packages` during venv creation - PR: #80
  - Add ability to create partial `.ptrconfig` files - PR: #83
  - Use native recursive file search for black and flake8 - PR: #81
  - Fix documentation for some new arguments - Thanks @omikader
  - Windows now defaults to updating pip + setuptools
  - Rely on setting current working directory with subprocess and remove coverage file environment setting
  - f-string everything via [flynt](https://pypi.org/project/flynt/) now we're >= 3.6
  - Enable pyre for Python 3.8 now it's fully supported
* Thu Jan  2 2020 Tomáš Chvátal <tchvatal@suse.com>
- Conflict with pytest-runner as we provide same file on the disk
* Mon Dec  9 2019 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
- Update to v19.11.21
* Tue Apr 16 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v19.3.5
